@@ -6,7 +6,7 @@
  * Date        : 2009-08-03
  * Description : digiKam config header
  *
- * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2020 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -82,7 +82,7 @@
 #define HAVE_PANORAMA 1
 
 /* Define to 1 if VKontakte tool is supported */
-#define HAVE_VKONTAKTE 1
+/* #undef HAVE_VKONTAKTE */
 
 /* Define to 1 if HTMLGallery tool is supported */
 #define HAVE_HTMLGALLERY 1
@@ -111,9 +111,6 @@
 /* Define to 1 if system use QWebEngine instead of QWebKit */
 #define HAVE_QWEBENGINE 1
 
-/* Define to 1 if FaceEngine DNN is enabled */
-#define HAVE_FACESENGINE_DNN 1
-
 /* Define to 1 if ImageMAgick codecs are supported */
 #define HAVE_IMAGE_MAGICK 1
 
